@@ -77,6 +77,8 @@ GDK_AVAILABLE_IN_ALL
 const char *      gdk_monitor_get_connector       (GdkMonitor   *monitor);
 GDK_AVAILABLE_IN_ALL
 int               gdk_monitor_get_scale_factor    (GdkMonitor   *monitor);
+GDK_AVAILABLE_IN_4_14
+double            gdk_monitor_get_scale           (GdkMonitor   *monitor);
 GDK_AVAILABLE_IN_ALL
 int               gdk_monitor_get_refresh_rate    (GdkMonitor   *monitor);
 GDK_AVAILABLE_IN_ALL
