@@ -77,6 +77,14 @@ GDK_AVAILABLE_IN_ALL
 void            gtk_snapshot_push_color_matrix          (GtkSnapshot            *snapshot,
                                                          const graphene_matrix_t*color_matrix,
                                                          const graphene_vec4_t  *color_offset);
+
+GDK_AVAILABLE_IN_4_20
+void            gtk_snapshot_push_component_transfer   (GtkSnapshot                *snapshot,
+                                                        const GskComponentTransfer *red,
+                                                        const GskComponentTransfer *green,
+                                                        const GskComponentTransfer *blue,
+                                                        const GskComponentTransfer *alpha);
+
 GDK_AVAILABLE_IN_ALL
 void            gtk_snapshot_push_repeat                (GtkSnapshot            *snapshot,
                                                          const graphene_rect_t  *bounds,
@@ -87,6 +95,14 @@ void            gtk_snapshot_push_clip                  (GtkSnapshot
 GDK_AVAILABLE_IN_ALL
 void            gtk_snapshot_push_rounded_clip          (GtkSnapshot            *snapshot,
                                                          const GskRoundedRect   *bounds);
+GDK_AVAILABLE_IN_4_14
+void            gtk_snapshot_push_fill                  (GtkSnapshot            *snapshot,
+                                                         GskPath                *path,
+                                                         GskFillRule             fill_rule);
+GDK_AVAILABLE_IN_4_14
+void            gtk_snapshot_push_stroke                (GtkSnapshot            *snapshot,
+                                                         GskPath                *path,
+                                                         const GskStroke        *stroke);
 GDK_AVAILABLE_IN_ALL
 void            gtk_snapshot_push_shadow                (GtkSnapshot            *snapshot,
                                                          const GskShadow        *shadow,
@@ -101,13 +117,16 @@ void            gtk_snapshot_push_mask                  (GtkSnapshot
 GDK_AVAILABLE_IN_ALL
 void            gtk_snapshot_push_cross_fade            (GtkSnapshot            *snapshot,
                                                          double                  progress);
-GDK_AVAILABLE_IN_ALL
+
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
+GDK_DEPRECATED_IN_4_16_FOR(GtkGLArea)
 void            gtk_snapshot_push_gl_shader             (GtkSnapshot            *snapshot,
                                                          GskGLShader            *shader,
                                                          const graphene_rect_t  *bounds,
                                                          GBytes                 *take_args);
-GDK_AVAILABLE_IN_ALL
+GDK_DEPRECATED_IN_4_16_FOR(GtkGLArea)
 void           gtk_snapshot_gl_shader_pop_texture       (GtkSnapshot            *snapshot);
+G_GNUC_END_IGNORE_DEPRECATIONS
 GDK_AVAILABLE_IN_ALL
 void            gtk_snapshot_pop                        (GtkSnapshot            *snapshot);
 GDK_AVAILABLE_IN_ALL
@@ -232,6 +251,16 @@ void            gtk_snapshot_append_layout              (GtkSnapshot
                                                          PangoLayout            *layout,
                                                          const GdkRGBA          *color);
 
+GDK_AVAILABLE_IN_4_14
+void            gtk_snapshot_append_fill                (GtkSnapshot            *snapshot,
+                                                         GskPath                *path,
+                                                         GskFillRule             fill_rule,
+                                                         const GdkRGBA          *color);
+GDK_AVAILABLE_IN_4_14
+void            gtk_snapshot_append_stroke              (GtkSnapshot            *snapshot,
+                                                         GskPath                *path,
+                                                         const GskStroke        *stroke,
+                                                         const GdkRGBA          *color);
 
 G_END_DECLS
 
